#
# spec file for package unar
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _dver  1.1
Name:           unar
Version:        1.10.8
Release:        1.4
Summary:        Multi-format unarchiver
License:        LGPL-2.1-or-later
URL:            https://unarchiver.c3.cx/commandline
Source0:        https://github.com/MacPaw/XADMaster/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.changes
Source2:        https://github.com/MacPaw/universal-detector/archive/%{_dver}/universal-detector-%{_dver}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  gcc-objc
BuildRequires:  gnustep-base-devel
BuildRequires:  gnustep-make
BuildRequires:  libbz2-devel
BuildRequires:  pkg-config
BuildRequires:  unzip
BuildRequires:  wavpack-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(icu-uc)

%description
The Unarchiver is originally a Mac OS X application. This package
contains a command-line variant of it. Unarchiver handles ZIP, ZIPX,
RAR, 7z, tar, gzip, bzip2, lzma, xz, CAB, MSI, NSIS, some
self-extracting EXEs, cpio, and further obscure and old formats, as
well as disc images in ISO, BIN, MDF, NRG, CDI. It supports filenames
in foreign character sets.

%prep
%setup -q -T -c
tar xf %{SOURCE0}
mv XADMaster-%{version} %{name}
tar -xf %{SOURCE2}
mv universal-detector-%{_dver} UniversalDetector

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="%{optflags}"
export OBJCFLAGS="$(gnustep-config --objc-flags)"
%make_build -C %{name} -f Makefile.linux

%install
install -d %{buildroot}%{_bindir}
install -m755 %{name}/lsar %{name}/unar -t %{buildroot}%{_bindir}
install -d %{buildroot}%{_mandir}/man1
install -m644 %{name}/Extra/lsar.1 %{name}/Extra/unar.1 -t %{buildroot}%{_mandir}/man1

install -d %{buildroot}%{_datadir}/bash-completion/completions
install -m644 %{name}/Extra/lsar.bash_completion %{buildroot}%{_datadir}/bash-completion/completions/lsar
install -m644 %{name}/Extra/unar.bash_completion %{buildroot}%{_datadir}/bash-completion/completions/unar

%files
%license %{name}/LICENSE
%doc %{name}/README.md
%{_bindir}/lsar
%{_bindir}/unar
%{_mandir}/man1/lsar.1%{?ext_man}
%{_mandir}/man1/unar.1%{?ext_man}
%{_datadir}/bash-completion/completions/lsar
%{_datadir}/bash-completion/completions/unar

%changelog
* Wed Nov 29 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.10.8
  * Fix a major memory leak in CSBzip2Handle
  * Fix Quarantine attribute for created directories
  * Fix crash corrupted iso
  * Fix crash during unarchive sitx format with symlink on
    deleted file
  * Implement Clang modules support
  * [TUN-189] Add Alternarive CRC calcuation for Mac Binary
    format
  * [WARC-1] Add basic support of WARC 1.1 archives
  * [TUN-138] Fix case with directories in Solid RAR5 archives
  * [TUN-184] Fix old archives with RAR 1.5
- Update source URL
- Add universal-detector as source
* Mon Sep 25 2023 Marcus Meissner <meissner@suse.com>
- use pkgconfig(icu-uc) to use the current libicu. (jsc#PED-6193)
* Wed Apr  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.10.7
  * Prevent using reference to dangling pointer for archives
    with password in interactive mode Fixes #112
  * Fix Undefined behaviour in lzw allocation
  * Return suggested path if we're running non-interactive (-q
    option was specified).
  * Fix incorrect comments parsing
  * Fix case when some permissions from Windows-generated
    archives were affecting files on Mac OS
  * Add tests for extended 64-Zip
  * Tests added, Fixes #101
  * Add tests for reading CDR
  * Add basic test for incorrect date conversion #99
  * Cleanup bufer after usage in tests
  * Check ZIP extra field if >= 9 bytes
- Drop Group tag
- Spec cleanup
* Tue Apr 23 2019 Kristýna Streitová <kstreitova@suse.com>
- update to version 1.10.5
  * Update/linux build validation
  * Remove wavpack sources from linux distribution
  * [TUN-62] Some symlinks aren't handled by the unarchiver
  * [TUN-62] Fix Symlink extration for certain files
  * Add faster IEEECRC32 calculation
  * Fix 7zip unarchivation for files with delta filter
  * Select correct Parser in conflicting SFX Archives
  * Correct RAR5 variable int reading for correct reading
    values >> 32 bit
  * Fix case when old solid rar archives weren't correctly extracted
  * Fix broken symbolic links for the archives, created in Windows
  * Fix case when JSON output explodes in solid archives with
    a lot of files
  * Support WARC 1.0 compliant WARC-Target-URI fields
  * Support extracting warc.{gz,bz2,lzma,xz,Z} files directly
  * Add support for self extracting archives in RAR5
- update fixes [bsc#1127736]
- remove the following patches (applied upstream)
  * use-system-wavpack.patch
  * document-undocumented-options.patch
  * unar-1.10.1-self-extracting_rar.patch
- change Source for the upstream tarball
* Wed Feb  6 2019 kstreitova@suse.com
- add unar-1.10.1-self-extracting_rar.patch to support RAR
  self-extracting (SFX) archives [bsc#1110754]
- fix bash completion path for lsar and unar
* Tue Mar 20 2018 kstreitova@suse.com
- revert changes from the last submission and move unrar_wrapper
  script to a separate package as it seems that openSUSE:Factory
  is not ready to obsolete unrar by unar yet [bsc#1083834],
  [fate#323896]
* Fri Feb 23 2018 kstreitova@suse.com
- add unrar_wrapper.py (https://github.com/openSUSE/unrar_wrapper)
  that provides the basic backwards compatibility with unrar
  [fate#323896]
- unar now obsoletes non-free unrar
- run spec-cleaner
* Mon Jan 23 2017 aloisio@gmx.com
- Added missing build dependency.
* Sun Jan 22 2017 aloisio@gmx.com
- Added -fno-strict-aliasing to CFLAGS to address some of the
  rpmlint warnings. The rest needs to be fixed upstream (see
  (https://bitbucket.org/WAHa_06x36/theunarchiver/issues/929)
- Added use-system-wavpack.patch and switched to system
  libwavpack (imported from debian)
- Added document-undocumented-options.patch (imported from
  debian)
* Sun Jan 15 2017 jengelh@inai.de
- Update description
* Wed Dec 14 2016 aloisio@gmx.com
- Initial package 1.10.1
